/*
 * Copyright E. Bigeon (2014)
 *
 * emmanuel@bigeon.fr
 *
 * This software is a computer program whose purpose is to
 * Socket implementation of GCLC.
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc-socket:fr.bigeon.gclc.socket.ConsoleRunnable.java
 * Created on: Jun 1, 2016
 */
package fr.bigeon.gclc.socket;

import fr.bigeon.gclc.ConsoleApplication;

/** A runnable class that will actually have the application running.
 *
 * @author Emmanuel Bigeon */
public class ConsoleRunnable implements Runnable {
    
    /** The actual application */
    private final ConsoleApplication app;
    /** The synchronization object */
    private final Object promptingLock;

    /** @param app the application
     * @param promptingLock the synchronization object */
    public ConsoleRunnable(ConsoleApplication app, Object promptingLock) {
        super();
        this.app = app;
        this.promptingLock = promptingLock;
    }

    /* (non-Javadoc)
     * @see java.lang.Runnable#run() */
    @Override
    public void run() {
        app.start();
        synchronized (promptingLock) {
            // release all waiting elements before ending
            promptingLock.notifyAll();
        }
    }

    /** Stop the application (it will finish its current operation) */
    public void stop() {
        app.exit();
    }

}
